==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/an/activity-stream-strings.js <==
// Note - this is a generated an file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nueva Pestanya",
  "header_top_sites": "Mas freqüents",
  "header_highlights": "Destacaus",
  "header_recommended_by": "Recomendau per {provider}",
  "context_menu_button_sr": "Ubrir menú contextual pa {title}",
  "section_context_menu_button_sr": "Ubrir lo menú contextual d'a sección",
  "type_label_visited": "Vesitau",
  "type_label_bookmarked": "Con marcapachinas",
  "type_label_recommended": "Tendencia",
  "type_label_pocket": "Alzau en Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Anyadir marcapachinas",
  "menu_action_remove_bookmark": "Sacar lo marcapachinas",
  "menu_action_open_new_window": "Ubrir en una nueva finestra",
  "menu_action_open_private_window": "Ubrir en una nueva finestra privada",
  "menu_action_dismiss": "Descartar",
  "menu_action_delete": "Eliminar de l'historial",
  "menu_action_pin": "Clavar",
  "menu_action_unpin": "Desclavar",
  "confirm_history_delete_p1": "Yes seguro que quiers borrar totas las instancias d'esta pachina en o tuyo historial?",
  "confirm_history_delete_notice_p2": "Esta acción no se puede desfer.",
  "menu_action_save_to_pocket": "Alzar en Pocket",
  "menu_action_delete_pocket": "Borrar de Pocket",
  "menu_action_archive_pocket": "Archivar en Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Mirar",
  "search_header": "Mirar con {search_engine_name}",
  "search_web_placeholder": "Mirar en o Web",
  "section_disclaimer_topstories": "Los articlos mas interesants d'o web, triaus en función d'o que gosas leyer. Gracias a lo Pocket, que agora ya fa parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Aprende cómo funciona",
  "section_disclaimer_topstories_buttontext": "Entendiu",
  "prefs_home_header": "Conteniu d'inicio de Firefox",
  "prefs_home_description": "Tría qué contenisu quiers veyer en a tuya pachina d'inicio de Firefox.",
  "prefs_section_rows_option": "{num} ringlera;{num} ringleras",
  "prefs_search_header": "Busqueda web",
  "prefs_topsites_description": "Los puestos que mas vesitas",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Saber-ne mas",
  "prefs_highlights_description": "Una tría d'os puestos que has alzau u vesitau",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Actualizacions de Mozilla y Firefox",
  "settings_pane_button_label": "Personaliza la tuya pachina de Nueva Pestanya",
  "settings_pane_topsites_header": "Puestos mas vesitaus",
  "settings_pane_highlights_header": "Destacaus",
  "settings_pane_highlights_options_bookmarks": "Marcapachinas",
  "settings_pane_snippets_header": "Retallos",
  "edit_topsites_button_text": "Editar",
  "edit_topsites_edit_button": "Editar este puesto",
  "topsites_form_add_header": "Nuevo puesto popular",
  "topsites_form_edit_header": "Editar lo puesto popular",
  "topsites_form_title_label": "Titol",
  "topsites_form_title_placeholder": "Escribir un titol",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL d'imachen personalizada",
  "topsites_form_url_placeholder": "Triar u apegar una adreza web",
  "topsites_form_use_image_link": "Usar una imachen personalizada…",
  "topsites_form_preview_button": "Previsualizar",
  "topsites_form_add_button": "Anyadir",
  "topsites_form_save_button": "Alzar",
  "topsites_form_cancel_button": "Cancelar",
  "topsites_form_url_validation": "Fa falta una URL valida",
  "topsites_form_image_validation": "Ha fallau la carga d'a imachen. Preba con una URL diferent.",
  "pocket_read_more": "Temas populars:",
  "pocket_read_even_more": "Amostrar mas articlos",
  "highlights_empty_state": "Empecipia a navegar, y t'iremos amostrando aquí grans articlos, videos y atras pachinas que has vesitau u marcau en zagueras.",
  "topstories_empty_state": "Ya ye tot per agora. Torna mas ta debant pa veyer mas articlos populars de {provider}. No i puetz aguardar? Tría un tema popular pa descubrir los articlos mas interesants de tot lo web.",
  "manual_migration_explanation2": "Preba lo Firefox con as adrezas d'interés, l'historial y las claus de belatro navegador.",
  "manual_migration_cancel_button": "No, gracias",
  "manual_migration_import_button": "Importar-lo agora",
  "error_fallback_default_info": "Oi, ha fallau bella cosa en a carga d'este conteniu.",
  "error_fallback_default_refresh_suggestion": "Refrescar la pachina pa tornar-lo a intentar.",
  "section_menu_action_remove_section": "Borrar la sección",
  "section_menu_action_collapse_section": "Plegar la sección",
  "section_menu_action_expand_section": "Desplegar la sección",
  "section_menu_action_manage_section": "Chestionar la sección",
  "section_menu_action_add_topsite": "Anyadir un puesto popular",
  "section_menu_action_move_up": "Puyar",
  "section_menu_action_move_down": "Baixar",
  "section_menu_action_privacy_notice": "Nota sobre privacidat",
  "prefs_restore_defaults_button": "Restaurar valors per defecto",
  "prefs_topstories_description": "Contenius d'alta calidat que no te quiers perder",
  "prefs_topstories_show_sponsored_label": "Articlos patrocinaus per {provider}",
  "settings_pane_header": "Preferencias de Nueva Pestanya",
  "settings_pane_body2": "Tría lo que veyes en esta pachina.",
  "settings_pane_search_header": "Mirar",
  "settings_pane_search_body": "Mirar la Web dende la tuya nueva pestanya.",
  "settings_pane_topsites_body": "Accede a los puestos web que mas vesitas.",
  "settings_pane_topsites_options_showmore": "Amostrar dos ringleras",
  "settings_pane_highlights_body2": "Torna a trobar lo mas interesant que has vesitau en zagueras, u que has marcau con marcapchinas.",
  "settings_pane_highlights_options_visited": "Puestos vesitaus",
  "settings_pane_snippets_body": "leye noticias curtas de Mozilla sobre lo Firefox, la cultura d'internet y, de cabo ta quan, bell meme.",
  "settings_pane_done_button": "Feito",
  "settings_pane_topstories_options_sponsored": "Amostrar articlos patrocinaus",
  "pocket_description": "Descubre gracias a Pocket, que dende agora fa parte de Mozilla, contenius d'alta calidat que d'atra manera te puetz perder."
};

==> firefox-62.0b18.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/an/activity-stream-strings.js <==
// Note - this is a generated an file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nueva Pestanya",
  "header_top_sites": "Mas freqüents",
  "header_highlights": "Destacaus",
  "header_recommended_by": "Recomendau per {provider}",
  "context_menu_button_sr": "Ubrir menú contextual pa {title}",
  "section_context_menu_button_sr": "Ubrir lo menú contextual d'a sección",
  "type_label_visited": "Vesitau",
  "type_label_bookmarked": "Con marcapachinas",
  "type_label_recommended": "Tendencia",
  "type_label_pocket": "Alzau en Pocket",
  "type_label_downloaded": "Descargau",
  "menu_action_bookmark": "Anyadir marcapachinas",
  "menu_action_remove_bookmark": "Sacar lo marcapachinas",
  "menu_action_open_new_window": "Ubrir en una nueva finestra",
  "menu_action_open_private_window": "Ubrir en una nueva finestra privada",
  "menu_action_dismiss": "Descartar",
  "menu_action_delete": "Eliminar de l'historial",
  "menu_action_pin": "Clavar",
  "menu_action_unpin": "Desclavar",
  "confirm_history_delete_p1": "Yes seguro que quiers borrar totas las instancias d'esta pachina en o tuyo historial?",
  "confirm_history_delete_notice_p2": "Esta acción no se puede desfer.",
  "menu_action_save_to_pocket": "Alzar en Pocket",
  "menu_action_delete_pocket": "Borrar de Pocket",
  "menu_action_archive_pocket": "Archivar en Pocket",
  "menu_action_show_file_mac_os": "Amostrar en o Finder",
  "menu_action_show_file_windows": "Ubrir la carpeta an que se troba",
  "menu_action_show_file_linux": "Ubrir la carpeta an que se troba",
  "menu_action_show_file_default": "Amostrar lo fichero",
  "menu_action_open_file": "Ubrir fichero",
  "menu_action_copy_download_link": "Copiar vinclo de descarga",
  "menu_action_go_to_download_page": "Ir ta la pachina de descarga",
  "menu_action_remove_download": "Borrar de l'historial",
  "search_button": "Mirar",
  "search_header": "Mirar con {search_engine_name}",
  "search_web_placeholder": "Mirar en o Web",
  "section_disclaimer_topstories": "Los articlos mas interesants d'o web, triaus en función d'o que gosas leyer. Gracias a lo Pocket, que agora ya fa parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Aprende cómo funciona",
  "section_disclaimer_topstories_buttontext": "Entendiu",
  "prefs_home_header": "Conteniu d'inicio de Firefox",
  "prefs_home_description": "Tría qué contenisu quiers veyer en a tuya pachina d'inicio de Firefox.",
  "prefs_section_rows_option": "{num} ringlera;{num} ringleras",
  "prefs_search_header": "Busqueda web",
  "prefs_topsites_description": "Los puestos que mas vesitas",
  "prefs_topstories_description2": "Contenius interesants de tot lo web, personalizau pa tu",
  "prefs_topstories_options_sponsored_label": "Articlos esponsorizaus",
  "prefs_topstories_sponsored_learn_more": "Saber-ne mas",
  "prefs_highlights_description": "Una tría d'os puestos que has alzau u vesitau",
  "prefs_highlights_options_visited_label": "Pachinas visitadas",
  "prefs_highlights_options_download_label": "Descarga mas recient",
  "prefs_highlights_options_pocket_label": "Pachinas alzadas en Pocket",
  "prefs_snippets_description": "Actualizacions de Mozilla y Firefox",
  "settings_pane_button_label": "Personaliza la tuya pachina de Nueva Pestanya",
  "settings_pane_topsites_header": "Puestos mas vesitaus",
  "settings_pane_highlights_header": "Destacaus",
  "settings_pane_highlights_options_bookmarks": "Marcapachinas",
  "settings_pane_snippets_header": "Retallos",
  "edit_topsites_button_text": "Editar",
  "edit_topsites_edit_button": "Editar este puesto",
  "topsites_form_add_header": "Nuevo puesto popular",
  "topsites_form_edit_header": "Editar lo puesto popular",
  "topsites_form_title_label": "Titol",
  "topsites_form_title_placeholder": "Escribir un titol",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL d'imachen personalizada",
  "topsites_form_url_placeholder": "Triar u apegar una adreza web",
  "topsites_form_use_image_link": "Usar una imachen personalizada…",
  "topsites_form_preview_button": "Previsualizar",
  "topsites_form_add_button": "Anyadir",
  "topsites_form_save_button": "Alzar",
  "topsites_form_cancel_button": "Cancelar",
  "topsites_form_url_validation": "Fa falta una URL valida",
  "topsites_form_image_validation": "Ha fallau la carga d'a imachen. Preba con una URL diferent.",
  "pocket_read_more": "Temas populars:",
  "pocket_read_even_more": "Amostrar mas articlos",
  "highlights_empty_state": "Empecipia a navegar, y t'iremos amostrando aquí grans articlos, videos y atras pachinas que has vesitau u marcau en zagueras.",
  "topstories_empty_state": "Ya ye tot per agora. Torna mas ta debant pa veyer mas articlos populars de {provider}. No i puetz aguardar? Tría un tema popular pa descubrir los articlos mas interesants de tot lo web.",
  "manual_migration_explanation2": "Preba lo Firefox con as adrezas d'interés, l'historial y las claus de belatro navegador.",
  "manual_migration_cancel_button": "No, gracias",
  "manual_migration_import_button": "Importar-lo agora",
  "error_fallback_default_info": "Oi, ha fallau bella cosa en a carga d'este conteniu.",
  "error_fallback_default_refresh_suggestion": "Refrescar la pachina pa tornar-lo a intentar.",
  "section_menu_action_remove_section": "Borrar la sección",
  "section_menu_action_collapse_section": "Plegar la sección",
  "section_menu_action_expand_section": "Desplegar la sección",
  "section_menu_action_manage_section": "Chestionar la sección",
  "section_menu_action_manage_webext": "Chestionar la extensión",
  "section_menu_action_add_topsite": "Anyadir un puesto popular",
  "section_menu_action_add_search_engine": "Anyadir motor de busqueda",
  "section_menu_action_move_up": "Puyar",
  "section_menu_action_move_down": "Baixar",
  "section_menu_action_privacy_notice": "Nota sobre privacidat",
  "firstrun_title": "Prene lo Firefox con tu",
  "firstrun_content": "Obtiene los tuyos marcapachinas, historials, claus y atros achustes en totz los tuyos dispositivos.",
  "firstrun_learn_more_link": "Aprende mas sobre las cuentas de Firefox",
  "firstrun_form_header": "Escribe lo tuyo email",
  "firstrun_form_sub_header": "pa continar enta Firefox Sync.",
  "firstrun_email_input_placeholder": "Correu-e",
  "firstrun_invalid_input": "Valid email required",
  "firstrun_extra_legal_links": "Si contina, ye confirmando que ye d'acuerdo con as {terms} y {privacy}.",
  "firstrun_terms_of_service": "Condicions d'uso",
  "firstrun_privacy_notice": "Nota sobre privacidat",
  "firstrun_continue_to_login": "Continar",
  "firstrun_skip_login": "Blinca-te este paso"
};
